@@ -5,7 +5,7 @@ from typing import Any, Optional, Union
 import click
 from lightning_cloud.openapi.rest import ApiException
 
-from lightning.app.cli.cmd_clusters import _check_cluster_name_is_valid, AWSClusterManager
+from lightning.app.cli.cmd_clusters import _check_cluster_id_is_valid, AWSClusterManager
 from lightning.app.cli.cmd_ssh_keys import _SSHKeyManager
 
 
@@ -16,7 +16,7 @@ def create() -> None:
 
 
 @create.command("cluster")
-@click.argument("cluster_name", callback=_check_cluster_name_is_valid)
+@click.argument("cluster_id", callback=_check_cluster_id_is_valid)
 @click.option("--provider", "provider", type=str, default="aws", help="cloud provider to be used for your cluster")
 @click.option("--external-id", "external_id", type=str, required=True)
 @click.option(
@@ -37,6 +37,7 @@ def create() -> None:
     type=bool,
     required=False,
     default=False,
+    hidden=True,
     is_flag=True,
     help=""""Use this flag to ensure that the cluster is created with a profile that is optimized for performance.
         This makes runs more expensive but start-up times decrease.""",
@@ -45,26 +46,27 @@ def create() -> None:
     "--edit-before-creation",
     default=False,
     is_flag=True,
+    hidden=True,
     help="Edit the cluster specs before submitting them to the API server.",
 )
 @click.option(
-    "--wait",
-    "wait",
+    "--async",
+    "do_async",
     type=bool,
     required=False,
     default=False,
     is_flag=True,
-    help="Enabling this flag makes the CLI wait until the cluster is running.",
+    help="This flag makes the CLI return immediately and lets the cluster creation happen in the background.",
 )
 def create_cluster(
-    cluster_name: str,
+    cluster_id: str,
     region: str,
     role_arn: str,
     external_id: str,
     provider: str,
     edit_before_creation: bool,
     enable_performance: bool,
-    wait: bool,
+    do_async: bool,
     **kwargs: Any,
 ) -> None:
     """Create a Lightning AI BYOC compute cluster with your cloud provider credentials."""
@@ -73,13 +75,13 @@ def create_cluster(
         return
     cluster_manager = AWSClusterManager()
     cluster_manager.create(
-        cluster_name=cluster_name,
+        cluster_id=cluster_id,
         region=region,
         role_arn=role_arn,
         external_id=external_id,
         edit_before_creation=edit_before_creation,
         cost_savings=not enable_performance,
-        wait=wait,
+        do_async=do_async,
     )
 
 
