@@ -1,3 +1,4 @@
+from lightning.app.components.auto_scaler import AutoScaler
 from lightning.app.components.database.client import DatabaseClient
 from lightning.app.components.database.server import Database
 from lightning.app.components.multi_node import (
@@ -15,6 +16,7 @@ from lightning.app.components.serve.streamlit import ServeStreamlit
 from lightning.app.components.training import LightningTrainerScript, PyTorchLightningScriptRunner
 
 __all__ = [
+    "AutoScaler",
     "DatabaseClient",
     "Database",
     "PopenPythonScript",
