@@ -1,19 +1,45 @@
 import abc
 import base64
+import os
+import platform
 from pathlib import Path
 from typing import Any, Dict, Optional
 
-import torch
 import uvicorn
 from fastapi import FastAPI
+from lightning_utilities.core.imports import compare_version, module_available
 from pydantic import BaseModel
-from starlette.staticfiles import StaticFiles
 
 from lightning.app.core.work import LightningWork
 from lightning.app.utilities.app_helpers import Logger
+from lightning.app.utilities.imports import _is_torch_available, requires
 
 logger = Logger(__name__)
 
+__doctest_skip__ = []
+# Skip doctests if requirements aren't available
+if not module_available("lightning_api_access"):
+    __doctest_skip__ += ["PythonServer", "PythonServer.*"]
+
+# Skip doctests if requirements aren't available
+if not _is_torch_available():
+    __doctest_skip__ += ["PythonServer", "PythonServer.*"]
+
+
+def _get_device():
+    import operator
+
+    import torch
+
+    _TORCH_GREATER_EQUAL_1_12 = compare_version("torch", operator.ge, "1.12.0")
+
+    local_rank = int(os.getenv("LOCAL_RANK", "0"))
+
+    if _TORCH_GREATER_EQUAL_1_12 and torch.backends.mps.is_available() and platform.processor() in ("arm", "arm64"):
+        return torch.device("mps", local_rank)
+    else:
+        return torch.device(f"cuda:{local_rank}" if torch.cuda.is_available() else "cpu")
+
 
 class _DefaultInputData(BaseModel):
     payload: str
@@ -43,6 +69,10 @@ class Number(BaseModel):
 
 
 class PythonServer(LightningWork, abc.ABC):
+
+    _start_method = "spawn"
+
+    @requires(["torch", "lightning_api_access"])
     def __init__(  # type: ignore
         self,
         host: str = "127.0.0.1",
@@ -60,39 +90,40 @@ class PythonServer(LightningWork, abc.ABC):
                 The default data type is good enough for the basic usecases and it expects the data
                 to be a json object that has one key called `payload`
 
-                ```
-                input_data = {"payload": "some data"}
-                ```
+                .. code-block:: python
+
+                    input_data = {"payload": "some data"}
 
                 and this can be accessed as `request.payload` in the `predict` method.
 
-                ```
-                def predict(self, request):
-                    data = request.payload
-                ```
+                .. code-block:: python
+
+                    def predict(self, request):
+                        data = request.payload
 
             output_type: Optional `output_type` to be provided. This needs to be a pydantic BaseModel class.
                 The default data type is good enough for the basic usecases. It expects the return value of
                 the `predict` method to be a dictionary with one key called `prediction`.
 
-                ```
-                def predict(self, request):
-                    # some code
-                    return {"prediction": "some data"}
-                ```
+                .. code-block:: python
+
+                    def predict(self, request):
+                        # some code
+                        return {"prediction": "some data"}
 
                 and this can be accessed as `response.json()["prediction"]` in the client if
                 you are using requests library
 
-        .. doctest::
+        Example:
 
             >>> from lightning.app.components.serve.python_server import PythonServer
             >>> from lightning.app import LightningApp
-            >>>
             ...
             >>> class SimpleServer(PythonServer):
+            ...
             ...     def setup(self):
             ...         self._model = lambda x: x + " " + x
+            ...
             ...     def predict(self, request):
             ...         return {"prediction": self._model(request.image)}
             ...
@@ -151,58 +182,44 @@ class PythonServer(LightningWork, abc.ABC):
         return out
 
     def _attach_predict_fn(self, fastapi_app: FastAPI) -> None:
+        from torch import inference_mode, no_grad
+
         input_type: type = self.configure_input_type()
         output_type: type = self.configure_output_type()
 
+        device = _get_device()
+        context = no_grad if device.type == "mps" else inference_mode
+
         def predict_fn(request: input_type):  # type: ignore
-            with torch.inference_mode():
+            with context():
                 return self.predict(request)
 
         fastapi_app.post("/predict", response_model=output_type)(predict_fn)
 
-    def _attach_frontend(self, fastapi_app: FastAPI) -> None:
-        from lightning_api_access import APIAccessFrontend
+    def configure_layout(self) -> None:
+        if module_available("lightning_api_access"):
+            from lightning_api_access import APIAccessFrontend
 
-        class_name = self.__class__.__name__
-        url = self._future_url if self._future_url else self.url
-        if not url:
-            # if the url is still empty, point it to localhost
-            url = f"http://127.0.0.1:{self.port}"
-        url = f"{url}/predict"
-        datatype_parse_error = False
-        try:
-            request = self._get_sample_dict_from_datatype(self.configure_input_type())
-        except TypeError:
-            datatype_parse_error = True
+            class_name = self.__class__.__name__
+            url = f"{self.url}/predict"
 
-        try:
-            response = self._get_sample_dict_from_datatype(self.configure_output_type())
-        except TypeError:
-            datatype_parse_error = True
+            try:
+                request = self._get_sample_dict_from_datatype(self.configure_input_type())
+                response = self._get_sample_dict_from_datatype(self.configure_output_type())
+            except TypeError:
+                return None
 
-        if datatype_parse_error:
-
-            @fastapi_app.get("/")
-            def index() -> str:
-                return (
-                    "Automatic generation of the UI is only supported for simple, "
-                    "non-nested datatype with types string, integer, float and boolean"
-                )
-
-            return
-
-        frontend = APIAccessFrontend(
-            apis=[
-                {
-                    "name": class_name,
-                    "url": url,
-                    "method": "POST",
-                    "request": request,
-                    "response": response,
-                }
-            ]
-        )
-        fastapi_app.mount("/", StaticFiles(directory=frontend.serve_dir, html=True), name="static")
+            return APIAccessFrontend(
+                apis=[
+                    {
+                        "name": class_name,
+                        "url": url,
+                        "method": "POST",
+                        "request": request,
+                        "response": response,
+                    }
+                ]
+            )
 
     def run(self, *args: Any, **kwargs: Any) -> Any:
         """Run method takes care of configuring and setting up a FastAPI server behind the scenes.
@@ -213,7 +230,6 @@ class PythonServer(LightningWork, abc.ABC):
 
         fastapi_app = FastAPI()
         self._attach_predict_fn(fastapi_app)
-        self._attach_frontend(fastapi_app)
 
         logger.info(f"Your app has started. View it in your browser: http://{self.host}:{self.port}")
         uvicorn.run(app=fastapi_app, host=self.host, port=self.port, log_level="error")
